package com.steerinfo.ems.emswebsocketlog.controller;

import com.steerinfo.auth.utils.JwtUtil;
import com.steerinfo.ems.Utils.DateUtils;
import com.steerinfo.ems.emswebsocketlog.model.EmsWebsocketLog;
import com.steerinfo.ems.emswebsocketlog.service.IEmsWebsocketLogService;
import com.steerinfo.framework.controller.BaseRESTfulController;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageList;
import com.steerinfo.framework.utils.collection.ListUtils;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Arrays;
import java.util.Date;
import java.util.HashMap;
import java.util.List;

/**
 * EmsWebsocketLog RESTful接口：
 * @author generator
 * @version 1.0-SNAPSHORT 2021-10-15 03:24
 * 类描述
 * 修订历史：
 * 日期：2021-10-15
 * 作者：generator
 * 参考：
 * 描述：EmsWebsocketLog RESTful接口
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@RestController
@RequestMapping("/${api.version}/emswebsocketlogs")
public class EmsWebsocketLogController extends BaseRESTfulController {

    @Autowired
    IEmsWebsocketLogService emsWebsocketLogService;

    @ApiOperation(value="获取列表", notes="分页查询")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
        @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer")
    })
    //@RequiresPermissions("emswebsocketlog:view")
    @GetMapping(value = "/")
    public RESTfulResult list(@RequestParam HashMap parmas,Integer pageNum, Integer pageSize){
        if ( parmas.get("relation") != null && "admin".equals(parmas.get("relation").toString())) {
            parmas.put("relation","");
        }
        PageList<EmsWebsocketLog> list = emsWebsocketLogService.queryForPage(parmas, pageNum, pageSize);
        return success(list);
    }

    @ApiOperation(value="获取列表", notes="分页模糊查询")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
        @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer")
    })
    //@RequiresPermissions("emswebsocketlog:view")
    @GetMapping(value = "/like/")
    public RESTfulResult listLike(@RequestParam HashMap parmas,Integer pageNum, Integer pageSize){
        if ( parmas.get("relation") != null && "admin".equals(parmas.get("relation").toString())) {
            parmas.put("relation","");
        }
        PageList<EmsWebsocketLog> list = emsWebsocketLogService.queryLikeForPage(parmas, pageNum, pageSize);
        return success(list);
    }
    
    @ApiOperation(value="创建", notes="根据EmsWebsocketLog对象创建")
    @ApiImplicitParam(name = "emsWebsocketLog", value = "详细实体emsWebsocketLog", required = true, dataType = "EmsWebsocketLog")
    //@RequiresPermissions("emswebsocketlog:create")
    @PostMapping(value = "/")
    public RESTfulResult add(@RequestBody EmsWebsocketLog model){
        model.setCreateman(JwtUtil.getUseridByToken());
        model.setCreatetime(DateUtils.dateStr(new Date(),"yyyy-MM-dd HH:mm:ss"));
        EmsWebsocketLog emsWebsocketLog = emsWebsocketLogService.add(model);
        return success(emsWebsocketLog);
    }

    @ApiOperation(value="获取详细信息", notes="根据url的id来获取详细信息")
    @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "String")
    //@RequiresPermissions("emswebsocketlog:view")
    @GetMapping(value = "/{id}")
    public RESTfulResult get(@PathVariable String id){
        EmsWebsocketLog emsWebsocketLog = emsWebsocketLogService.getById(id);
        return success(emsWebsocketLog);
    }

    @ApiOperation(value="更新详细信息", notes="根据url的id来指定更新对象，并根据传过来的emsWebsocketLog信息来更新详细信息")
    @ApiImplicitParams({
        @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "String"),
        @ApiImplicitParam(name = "emsWebsocketLog", value = "详细实体emsWebsocketLog", required = true, dataType = "EmsWebsocketLog")
    })
    //@RequiresPermissions("emswebsocketlog:update")
    @PutMapping(value = "/{id}", produces  = "application/json;charset=UTF-8")
    public RESTfulResult update(@PathVariable String id, @RequestBody EmsWebsocketLog model){
        model.setId(id);
        model.setCloseman(JwtUtil.getUseridByToken());
        model.setClosetime(DateUtils.dateStr(new Date(),"yyyy-MM-dd HH:mm:ss"));
        EmsWebsocketLog emsWebsocketLog = emsWebsocketLogService.modify(model);
        return success(emsWebsocketLog);
    }

    @ApiOperation(value="删除", notes="根据url的id来指定删除对象")
    @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "String")
    //@RequiresPermissions("emswebsocketlog:delete")
    @DeleteMapping(value = "/{id}")//String
    public RESTfulResult delete(@PathVariable String id){
    	List<String> list = Arrays.asList(id.split(","));
    	if(ListUtils.isNotEmpty(list)) {
	    	List<String> ids = ListUtils.convertList(list);
			  emsWebsocketLogService.delete(ids);
    	}
      return success();
    }
    @ApiOperation(value="更新详细信息", notes="根据根据传过来的emsWebsocketLog信息来更新详细信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "emsWebsocketLog", value = "详细实体emsWebsocketLog", required = true, dataType = "EmsWebsocketLog")
    })
    @PutMapping(value = "/batchupdate", produces  = "application/json;charset=UTF-8")
    public RESTfulResult batchupdate(@RequestBody EmsWebsocketLog[] models) {
        String userId = JwtUtil.getUseridByToken();
        for (int i = 0; i < models.length; i++) {
            EmsWebsocketLog model = models[i];
            if (model.getId() == null || model.getId().equals("")) {
                return failed(null, "id为空");
            }
            model.setState("1");
            model.setClosetime(DateUtils.dateStr(new Date(),"yyyy-MM-dd HH:mm:ss"));
            model.setCloseman(JwtUtil.getUseridByToken());
            emsWebsocketLogService.modify(model);
        }
        return success();
    }
}
